# HDXMS Datasets

Welcome to the HDXMS datasets repository. 

The aim of this repository is to provide python bindings for downloading and loading curated bottom-up HDX-MS datasets.

The repository of curated datasets is available elsewhere on [GitHub](https://github.com/Jhsmit/HDX-MS-datasets) and is
currently the default remote data repository.

## Installation

```bash
$ pip install hdxms-datasets
```